<Connection>
  <% if @host -%>
  Host "<%= @host %>"
  <% end -%>
  ServiceURL "<%= @service_url %>"
  <% @collect.each do |collect| -%>
  Collect "<%= collect %>"
  <% end -%>
  <% if @user -%>
  User "<%= @user %>"
  <% end -%>
  <% if @password -%>
  Password "<%= @password %>"
  <% end -%>
  <% if @instance_prefix -%>
  InstancePrefix "<%= @instance_prefix %>"
  <% end -%>
</Connection>
