<Plugin disk>
<% @disks.each do |disk| -%>
  Disk  "<%=disk %>"
<% end -%>
  IgnoreSelected <%= @ignoreselected %>
<% if @udevnameattr and scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.5']) >= 0) -%>
  UdevNameAttr <%= @udevnameattr %>
<% end -%>
</Plugin>
