<Plugin write_tsdb>
   <Node>
     Host "<%= @host  %>"
     Port "<%= @port  %>"
     HostTags "<%= @host_tags.join(' ') %>"
     StoreRates <%= @store_rates %>
     AlwaysAppendDS <%= @always_append_ds %>
   </Node>
</Plugin>
