<Plugin unixsock>
  SocketFile  "<%= @socketfile %>"
  SocketGroup "<%= @socketgroup %>"
  SocketPerms "<%= @socketperms %>"
<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5']) >= 0) -%>
  DeleteSocket "<%= @deletesocket %>"
<% end -%>
</Plugin>
