<Plugin "apache">
  <Instance "<%= @name %>">
    URL "<%= @url %>"
<% if @user -%>
    User "<%= @user %>"
<% end -%>
<% if @password -%>
    Password "<%= @password %>"
<% end -%>
<% if defined? @verifypeer -%>
    VerifyPeer <%= @verifypeer %>
<% end -%>
<% if defined? @verifyhost -%>
    VerifyHost <%= @verifyhost %>
<% end -%>
<% if @cacert -%>
    CACert "<%= @cacert %>"
<% end -%>
<% if @sslciphers -%>
    SSLCiphers "<%= @sslciphers %>"
<% end -%>
<% if @timeout -%>
    Timeout <%= @timeout %>
<% end -%>
  </Instance>
</Plugin>
