<Plugin sensors>
<% if @sensorconfigfile -%>
  SensorConfigFile "<%= @sensorconfigfile %>"
<% end -%>
<% if @sensors -%>
<% @sensors.each do |sensor| -%>
  Sensor "<%= sensor %>"
<% end -%>
<% end -%>
<% unless @ignoreselected.nil? -%>
  IgnoreSelected <%= @ignoreselected %>
<% end -%>
</Plugin>
