<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.5']) >= 0) -%>
<Plugin "write_log">
  Format "<%= @format %>"
</Plugin>
<% end -%>
