<% if @options.nil? -%>
    Target "<%= @plugin %>"
<% else -%>
    <Target "<%= @plugin %>">
<%  @options.each do |key, value| -%>
<%    if value.kind_of?(String) -%>
      <%= key %> "<%= value %>"
<%    elsif value.kind_of?(Integer) or value.kind_of?(Float) or value.kind_of?(TrueClass) or value.kind_of?(FalseClass) -%>
      <%= key %> <%= value %>
<%    elsif value.kind_of?(Array) -%>
			<% value.each do |array_val| -%>
						<%= key %> <%= array_val %>
			<%    end -%>
<%    end -%>
<%  end -%>
    </Target>
<% end -%>
