<Plugin statsd>
<% if @host -%>
  Host "<%= @host %>"
<% end -%>
<% if @port -%>
  Port <%= @port %>
<% end -%>
<% unless @deletecounters.nil? -%>
  DeleteCounters <%= @deletecounters %>
<% end -%>
<% unless @deletetimers.nil? -%>
  DeleteTimers <%= @deletetimers %>
<% end -%>
<% unless @deletegauges.nil? -%>
  DeleteGauges <%= @deletegauges %>
<% end -%>
<% unless @deletesets.nil? -%>
  Deletesets <%= @deletesets %>
<% end -%>
<% unless @countersum.nil? -%>
  CounterSum <%= @countersum %>
<% end -%>
<% @timerpercentile.each do |percentile| -%>
  TimerPercentile <%= percentile %>
<% end -%>
<% if @timerupper -%>
  TimerUpper <%= @timerupper %>
<% end -%>
<% if @timerlower -%>
  TimerLower <%= @timerlower %>
<% end -%>
<% if @timersum -%>
  TimerSum <%= @timersum %>
<% end -%>
<% if @timercount -%>
  TimerCount <%= @timercount %>
<% end -%>
</Plugin>
