# Generated by Puppet

<Plugin "tail">
 <File "<%= @filename %>">
  Instance "<%= @instance %>"
<% @matches.each do |match| -%>
  <Match>
   Regex "<%= match['regex'] %>"
<% if match['excluderegex'] -%>
   ExcludeRegex "<%= match['excluderegex'] %>"
<% end -%>
   DSType "<%= match['dstype'] %>"
   Type "<%= match['type'] %>"
   Instance "<%= match['instance'] %>"
  </Match>
<% end -%>
 </File>
</Plugin>
