<% @matches.each do |match| -%>
  <Match>
    Regex "<%= match['regex'] %>"
<% unless match['excluderegex'].nil? -%>
    ExcludeRegex "<%= match['excluderegex'] %>"
<% end -%>
    DSType "<%= match['dstype'] %>"
    Type "<%= match['type'] %>"
<% if match['instance'] -%>
    Instance "<%= match['instance'] %>"
<% end -%>
  </Match>
<% end -%>
