<%- if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.3']) >= 0) -%>
<Node "<%= @title %>">
<%- else -%>
<Carbon>
<%- end -%>
  Host "<%= @graphitehost %>"
  Port "<%= @graphiteport %>"
  Prefix "<%= @graphiteprefix %>"
<%- if @graphitepostfix -%>
  Postfix "<%= @graphitepostfix %>"
<%- end -%>
  EscapeCharacter "<%= @escapecharacter %>"
  StoreRates <%=  @storerates %>
  AlwaysAppendDS <%= @alwaysappendds %>
  SeparateInstances <%= @separateinstances %>
<%- if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.4']) >= 0) -%>
  LogSendErrors <%= @logsenderrors %>
  Protocol "<%= @protocol %>"
<%- end -%>
<%- if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.3']) >= 0) -%>
</Node>
<%- else -%>
</Carbon>
<%- end -%>
