<Plugin df>
<% @devices.each do |dev| -%>
  Device "<%= dev %>"
<% end -%>
<% @mountpoints.each do |mp| -%>
  MountPoint "<%= mp %>"
<% end -%>
<% @fstypes.each do |fs| -%>
  FSType "<%= fs %>"
<% end -%>
  IgnoreSelected <%= @ignoreselected %>
  ReportByDevice <%= @reportbydevice %>
  ReportInodes <%= @reportinodes %>
<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.5']) < 0) -%>
  ReportReserved <%= @reportreserved %>
<% end -%>
<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.4']) >= 0) -%>
  ValuesAbsolute <%= @valuesabsolute %>
  ValuesPercentage <%= @valuespercentage %>
<% end -%>
</Plugin>
