<Plugin openvpn>
<% @statusfiles.each do |sf| -%>
  StatusFile "<%= sf %>"
<% end -%>
  ImprovedNamingSchema <%= @improvednamingschema %>
  CollectCompression <%= @collectcompression %>
  CollectIndividualUsers <%= @collectindividualusers %>
  CollectUserCount <%= @collectusercount %>
</Plugin>
