<Plugin network>
<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '4.7']) >= 0) -%>
  <Listen "<%= @name %>" "<%= @port %>">
<% if @securitylevel -%>
    SecurityLevel "<%= @securitylevel %>"
<% end -%>
<% if @authfile -%>
    AuthFile "<%= @authfile %>"
<% end -%>
<% if @interface -%>
    Interface "<%= @interface %>"
<% end %>
  </Listen>
<% else -%>
  Listen "<%= @name %>" "<%= @port %>"
<% end -%>
</Plugin>
