# Generated by Puppet
<% unless @fqdnlookup %>
Hostname "<%= @collectd_hostname %>"
FQDNLookup false
<% else %>
#Hostname localhost
FQDNLookup true
<% end %>
<% if @autoloadplugin -%>
AutoLoadPlugin true
<% else -%>
AutoLoadPlugin false
<% end -%>
#BaseDir "/var/lib/collectd"
#PluginDir "/usr/lib/collectd"
<% if @typesdb and not @typesdb.empty? -%>
TypesDB<% @typesdb.each do |path| -%> "<%= path %>"<% end %>
<% end -%>
<% if @write_queue_limit_high -%>
WriteQueueLimitHigh <%= @write_queue_limit_high %>
<% end -%>
<% if @write_queue_limit_low -%>
WriteQueueLimitLow <%= @write_queue_limit_low %>
<% end -%>
Interval <%= @interval %>
Timeout <%= @timeout %>
ReadThreads <%= @read_threads %>
WriteThreads <%= @write_threads %>
<% if @has_wordexp  == true -%>
Include "<%= @plugin_conf_dir %>/*.conf"
<% else -%>
Include "<%= @plugin_conf_dir %>/"
<% end -%>
<% @include.each do |obj| -%>
Include "<%= obj %>"
<% end -%>
<% if @internal_stats && scope.lookupvar('collectd::collectd_version_real') && scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.5']) > 0 -%>
CollectInternalStats true
<% end -%>
