# Generated by Puppet
<% if scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '4.9.4']) >= 0) -%>
<LoadPlugin <%= @plugin %>>
  Globals <%= @globals %>
<% if @flushinterval and scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.2']) >= 0) -%>
  FlushInterval <%= @flushinterval %>
<% end -%>
<% if @interval and scope.lookupvar('collectd::collectd_version_real') and (scope.function_versioncmp([scope.lookupvar('collectd::collectd_version_real'), '5.2']) >= 0) -%>
  Interval <%= @interval %>
<% end -%>
</LoadPlugin>
<% else -%>
LoadPlugin <%= @plugin %>
<% end -%>

<%= @content %>
